Module runtime

Module runtime 

Internal asynchronous runtime wrappers.

Modules

task
Asynchronous green-threads.
time
Utilities for tracking time.

Functions

spawn
Spawns a new asynchronous task, returning a JoinHandle for it.

Attribute Macros

async_trait
main
Marks async function to be executed by the selected runtime. This macro helps set up a Runtime without requiring the user to use Runtime or Builder directly.