Crate rullst

Crate rullst 

Rullst Core Library

Re-exports

pub use routing::Router;
pub use server::Server;
pub use config::AppConfig;
pub use config::DatabaseConfig;
pub use config::RullstConfig;
pub use config::SecurityConfig;
pub use htmx::HtmxRequest;
pub use htmx::HtmxResponse;
pub use htmx::render_page;
pub use cache::Cache;
pub use queue::Queue;
pub use queue::QueuedJobDetail;
pub use queue::Worker;
pub use scheduler::Scheduler;
pub use mail::Mail;
pub use mail::Message as MailMessage;
pub use storage::Storage;
pub use storage::StorageDriver;
pub use storage::StorageError;
pub use validation::ValidatedForm;
pub use validation::ValidatedJson;
pub use validation::ValidationError;
pub use ws::WebSocket;
pub use ws::WsError;
pub use resilience::RateLimitConfig;
pub use resilience::RateLimiter;
pub use resilience::TrafficShield;
pub use resilience::TrafficShieldConfig;
pub use resilience::backpressure_middleware;
pub use resilience::rate_limit_middleware;
pub use ai::AiClient;
pub use ai::AiError;
pub use ai::AiProvider;
pub use ai::ChatBuilder;
pub use ai::Message as AiMessage;
pub use ai::VectorDocument;
pub use ai::VectorIndex;
pub use feature::DbFeatureDriver;
pub use feature::EnvFeatureDriver;
pub use feature::FeatureDriver;
pub use feature::FeatureManager;
pub use feature::MemoryFeatureDriver;
pub use feature::TomlFeatureDriver;
pub use multitenant::TenantConfig;
pub use multitenant::TenantLayer;
pub use multitenant::TenantService;
pub use multitenant::TenantStrategy;
pub use multitenant::tenant_layer;
pub use testing::TestApp;
pub use testing::TestRequestBuilder;
pub use testing::TestResponse;
pub use nexus::FieldKind;
pub use nexus::FieldMeta;
pub use nexus::Nexus;
pub use nexus::NexusModel;
pub use capital::BillingProvider;
pub use capital::LemonSqueezyProvider;
pub use capital::StripeProvider;
pub use capital::SubscriptionStatus;
pub use capital::WebhookEvent;

Modules

ai
AI integrations (e.g. Chat, Vector indices, Embeddings).
artisan
Artisan command-line migrations and seed execution helpers.
async_runtime
Re-exported underlying asynchronous engine (Tokio).
auth
Complete authentication system supporting session, JWT, and Passkey.
cache
Rullst Cache System (rullst::cache)
capital
Rullst Capital
client
Edge client components rendering module.
config
Rullst application and server configuration models.
db
Rullst Database Extensions (rullst::db)
edge
Rullst Edge Runtime (rullst::edge)
email_client
Re-exported email client engine (Lettre).
error_console
HTML visual logging and runtime console for development mode.
feature
Feature flagging management and drivers.
horizon
Background job queues monitoring panel (Horizon).
html
Fast compile-time HTML rendering utilities.
htmx
HTMX helpers for rapid reactive UI design.
live
Live state synchronization and server-push connection handlers.
mail
Unified mail delivery and dispatch drivers.
multitenant
Multitenancy request routing and tenant state isolation layers.
nexus
Rullst Nexus Panel
queue
Rullst Queue System (rullst::queue)
resilience
Network and service resilience (rate limits, traffic shield, load shedding).
response
Standard HTTP response types and helpers.
routing
High-performance application routers built on Axum.
runtime
Internal asynchronous runtime wrappers.
scheduler
Rullst Task Scheduler (rullst::scheduler)
security
CSRF tokens, CORS, and response headers security policies.
server
Rullst HTTP web server core engine.
storage
File and cloud storage abstraction layer.
studio
Developer’s Studio dashboard for database, logs, and queue analytics.
testing
Scaffolding tools for robust integration testing.
validation
Strongly-typed request validation extractors.
web
Web server engine re-exports (Axum, Tower, Tower-HTTP).
ws
WebSocket live connection and messaging system.

Macros

artisan
Standard migration and seeding bootstrap macro for Rullst.
html
A macro for writing HTML inline in Rust. It compiles down to highly optimized string concatenations at compile time, and automatically escapes dynamic variables to prevent XSS.
routes
Declarative macro for building a Router from a list of HTTP route definitions.

Structs

Orm
Orm configuration structure

Traits

RullstModel
The core trait that all Orm models will implement via #[derive(Orm)]
Validate
This is the original trait that was implemented by deriving Validate. It will still be implemented for struct validations that don’t take custom arguments. The call is being forwarded to the ValidateArgs<'v_a> trait.

Attribute Macros

async_trait
client_component
Proc macro attribute to define a Wasm Island client component.

Derive Macros

Orm
Validate