Crate rullst

Crate rullst 

Re-exports

pub use routing::Router;
pub use server::Server;

Modules

artisan
html
response
routing
server

Macros

artisan
html
A macro for writing HTML inline in Rust. It compiles down to highly optimized string concatenations at compile time, and automatically escapes dynamic variables to prevent XSS.
routes

Structs

Eloquent
Eloquent configuration structure

Traits

EloquentModel
The core trait that all Eloquent models will implement via #[derive(Eloquent)]

Derive Macros

Eloquent