pub struct Extension<T>(pub T);Expand description
Extractor and response for extensions.
As extractor
This is commonly used to share state across handlers.
use axum::{
Router,
Extension,
routing::get,
};
use std::sync::Arc;
// Some shared state used throughout our application
struct State {
// ...
}
async fn handler(state: Extension<Arc<State>>) {
// ...
}
let state = Arc::new(State { /* ... */ });
let app = Router::new().route("/", get(handler))
// Add middleware that inserts the state into all incoming request's
// extensions.
.layer(Extension(state));If the extension is missing it will reject the request with a 500 Internal Server Error response. Alternatively, you can use Option<Extension<T>> to
make the extension extractor optional.
As response
Response extensions can be used to share state with middleware.
use axum::{
Extension,
response::IntoResponse,
};
async fn handler() -> (Extension<Foo>, &'static str) {
(
Extension(Foo("foo")),
"Hello, World!"
)
}
#[derive(Clone)]
struct Foo(&'static str);Tuple Fields
0: TTrait Implementations
impl<T> Copy for Extension<T>where
T: Copy,
Sourceimpl<T, S> FromRequestParts<S> for Extension<T>
impl<T, S> FromRequestParts<S> for Extension<T>
Sourcetype Rejection = ExtensionRejection
type Rejection = ExtensionRejection
If the extractor fails itโll use this โrejectionโ type. A rejection is
a kind of error that can be converted into a response.
Sourceasync fn from_request_parts(
req: &mut Parts,
_state: &S,
) -> Result<Extension<T>, <Extension<T> as FromRequestParts<S>>::Rejection>
async fn from_request_parts( req: &mut Parts, _state: &S, ) -> Result<Extension<T>, <Extension<T> as FromRequestParts<S>>::Rejection>
Perform the extraction.
Sourceimpl<T> IntoResponse for Extension<T>
impl<T> IntoResponse for Extension<T>
Sourcefn into_response(self) -> Response<Body>
fn into_response(self) -> Response<Body>
Create a response.
Sourceimpl<T> IntoResponseParts for Extension<T>
impl<T> IntoResponseParts for Extension<T>
Sourcetype Error = Infallible
type Error = Infallible
The type returned in the event of an error. Read more
Sourcefn into_response_parts(
self,
res: ResponseParts,
) -> Result<ResponseParts, <Extension<T> as IntoResponseParts>::Error>
fn into_response_parts( self, res: ResponseParts, ) -> Result<ResponseParts, <Extension<T> as IntoResponseParts>::Error>
Set parts of the response
Sourceimpl<T, S> OptionalFromRequestParts<S> for Extension<T>
impl<T, S> OptionalFromRequestParts<S> for Extension<T>